"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.ConditionalTypeSchema = void 0;
function _schemaNode() {
  const data = require("../schema-node");
  _schemaNode = function () {
    return data;
  };
  return data;
}
function _schemaRegistry() {
  const data = require("../schema-registry");
  _schemaRegistry = function () {
    return data;
  };
  return data;
}
/**
 * e.g. `T extends U ? Y : N`
 *
 */
class ConditionalTypeSchema extends _schemaNode().SchemaNode {
  constructor(location, checkType, extendsType, trueType, falseType) {
    super();
    this.location = location;
    this.checkType = checkType;
    this.extendsType = extendsType;
    this.trueType = trueType;
    this.falseType = falseType;
  }
  getNodes() {
    return [this.checkType, this.extendsType, this.trueType, this.falseType];
  }
  toString() {
    return `${this.checkType.toString()} extends ${this.extendsType.toString()} ? ${this.trueType.toString()} : ${this.falseType.toString()}`;
  }
  toFullSignature(options) {
    const checkTypeStr = this.checkType.toFullSignature(options);
    const extendsTypeStr = this.extendsType.toFullSignature(options);
    const trueTypeStr = this.trueType.toFullSignature(options);
    const falseTypeStr = this.falseType.toFullSignature(options);
    return `${checkTypeStr} extends ${extendsTypeStr} ? ${trueTypeStr} : ${falseTypeStr}`;
  }
  toObject() {
    return {
      ...super.toObject(),
      checkType: this.checkType.toObject(),
      extendsType: this.extendsType.toObject(),
      trueType: this.trueType.toObject(),
      falseType: this.falseType.toObject()
    };
  }
  static fromObject(obj) {
    const location = obj.location;
    const checkType = _schemaRegistry().SchemaRegistry.fromObject(obj.checkType);
    const extendsType = _schemaRegistry().SchemaRegistry.fromObject(obj.extendsType);
    const trueType = _schemaRegistry().SchemaRegistry.fromObject(obj.trueType);
    const falseType = _schemaRegistry().SchemaRegistry.fromObject(obj.falseType);
    return new ConditionalTypeSchema(location, checkType, extendsType, trueType, falseType);
  }
}
exports.ConditionalTypeSchema = ConditionalTypeSchema;

//# sourceMappingURL=conditional-type.js.map