"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.DecoratorSchema = void 0;
function _schemaNode() {
  const data = require("../schema-node");
  _schemaNode = function () {
    return data;
  };
  return data;
}
function _schemaRegistry() {
  const data = require("../schema-registry");
  _schemaRegistry = function () {
    return data;
  };
  return data;
}
function _docs() {
  const data = require("./docs");
  _docs = function () {
    return data;
  };
  return data;
}
class DecoratorSchema extends _schemaNode().SchemaNode {
  constructor(location, name, doc, args) {
    super();
    this.location = location;
    this.name = name;
    this.doc = doc;
    this.args = args;
  }
  getNodes() {
    return this.args || [];
  }
  toString() {
    const argsStr = this.args?.map(arg => arg.toString()).join(', ');
    return `@${this.name}${argsStr ? `(${argsStr})` : ''}`;
  }
  toFullSignature(options) {
    let result = '';
    if (options?.showDocs && this.doc) {
      result += `${this.doc.toFullSignature()}\n`;
    }
    const argsStr = this.args?.map(arg => arg.toFullSignature(options)).join(', ');
    result += `@${this.name}${argsStr ? `(${argsStr})` : ''}`;
    return result;
  }
  toObject() {
    return {
      ...super.toObject(),
      name: this.name,
      doc: this.doc?.toObject(),
      args: this.args?.map(arg => arg.toObject())
    };
  }
  static fromObject(obj) {
    const location = obj.location;
    const name = obj.name;
    const doc = obj.doc ? _docs().DocSchema.fromObject(obj.doc) : undefined;
    const args = obj.args ? obj.args.map(arg => _schemaRegistry().SchemaRegistry.fromObject(arg)) : undefined;
    return new DecoratorSchema(location, name, doc, args);
  }
}
exports.DecoratorSchema = DecoratorSchema;

//# sourceMappingURL=decorator.js.map