"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.PropertyLikeTagSchema = void 0;
function _schemaRegistry() {
  const data = require("../../schema-registry");
  _schemaRegistry = function () {
    return data;
  };
  return data;
}
function _tag() {
  const data = require("./tag");
  _tag = function () {
    return data;
  };
  return data;
}
/**
 * e.g. `@param myParam {string} some comment`
 */
class PropertyLikeTagSchema extends _tag().TagSchema {
  constructor(location, name, comment, type) {
    super(location, _tag().TagName.parameter, comment);
    this.location = location;
    this.name = name;
    this.comment = comment;
    this.type = type;
  }
  toString() {
    const comment = this.comment ? ` ${this.comment}` : '';
    const type = this.type ? ` {${this.type.toString()}} ` : '';
    return `@${this.tagName} ${this.name}${type} ${comment}`;
  }
  toFullSignature(options) {
    const typeStr = this.type ? ` {${this.type.toFullSignature(options)}} ` : '';
    const comment = this.comment ? ` ${this.comment}` : '';
    return `@${this.tagName} ${this.name}${typeStr}${comment}`;
  }
  toObject() {
    return {
      ...super.toObject(),
      name: this.name,
      type: this.type?.toObject()
    };
  }
  static fromObject(obj) {
    const location = obj.location;
    const name = obj.name;
    const comment = obj.comment;
    const type = obj.type ? _schemaRegistry().SchemaRegistry.fromObject(obj.type) : undefined;
    return new PropertyLikeTagSchema(location, name, comment, type);
  }
}
exports.PropertyLikeTagSchema = PropertyLikeTagSchema;

//# sourceMappingURL=property-like-tag.js.map