"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.EnumSchema = void 0;
function _chalk() {
  const data = _interopRequireDefault(require("chalk"));
  _chalk = function () {
    return data;
  };
  return data;
}
function _schemaNode() {
  const data = require("../schema-node");
  _schemaNode = function () {
    return data;
  };
  return data;
}
function _docs() {
  const data = require("./docs");
  _docs = function () {
    return data;
  };
  return data;
}
function _() {
  const data = require("..");
  _ = function () {
    return data;
  };
  return data;
}
function _interopRequireDefault(e) { return e && e.__esModule ? e : { default: e }; }
class EnumSchema extends _schemaNode().SchemaNode {
  constructor(location, name, members, signature, doc) {
    super();
    this.location = location;
    this.name = name;
    this.signature = signature;
    this.doc = doc;
    this.members = members;
  }
  getNodes() {
    return this.members;
  }
  toString(options) {
    const boldUnderline = options?.color ? _chalk().default.bold.underline : str => str;
    const membersStr = this.members.map(m => `* ${m.toString(options)}`).join('\n');
    return `${boldUnderline(this.name)}\n${membersStr}`;
  }
  toFullSignature(options) {
    let result = '';
    if (options?.showDocs && this.doc) {
      result += `${this.doc.toFullSignature()}\n`;
    }
    result += `enum ${this.name} {\n`;
    const membersStr = this.members.map(member => {
      const memberStr = member.toFullSignature(options);
      return `  ${memberStr}`;
    }).join(',\n');
    result += `${membersStr}\n`;
    result += `}`;
    return result;
  }
  toObject() {
    return {
      ...super.toObject(),
      name: this.name,
      members: this.members.map(member => member.toObject()),
      doc: this.doc?.toObject(),
      signature: this.signature
    };
  }
  static fromObject(obj) {
    const location = obj.location;
    const name = obj.name;
    const members = obj.members.map(member => _().SchemaRegistry.fromObject(member));
    const signature = obj.signature;
    const doc = obj.doc ? _docs().DocSchema.fromObject(obj.doc) : undefined;
    return new EnumSchema(location, name, members, signature, doc);
  }
}
exports.EnumSchema = EnumSchema;

//# sourceMappingURL=enum.js.map