"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.ExportSchema = void 0;
function _schemaNode() {
  const data = require("../schema-node");
  _schemaNode = function () {
    return data;
  };
  return data;
}
function _docs() {
  const data = require("./docs");
  _docs = function () {
    return data;
  };
  return data;
}
function _schemaRegistry() {
  const data = require("../schema-registry");
  _schemaRegistry = function () {
    return data;
  };
  return data;
}
class ExportSchema extends _schemaNode().SchemaNode {
  constructor(location, name, exportNode, alias, doc) {
    super();
    this.location = location;
    this.name = name;
    this.exportNode = exportNode;
    this.alias = alias;
    this.doc = doc;
    this.signature = exportNode.signature || this.toFullSignature();
  }
  toString(options) {
    let signature = '';
    const alias = this.alias || this.name;
    const originalName = this.exportNode.name || this.name;
    if (alias !== originalName) {
      signature += `export { ${originalName} as ${alias} };\n`;
    } else {
      signature += `export { ${originalName} };\n`;
    }
    const exportNodeSignature = this.exportNode.toString(options);
    signature += `\n${exportNodeSignature}`;
    return signature;
  }
  toFullSignature(options) {
    let signature = '';
    if (options?.showDocs && this.doc) {
      const docString = this.doc.toFullSignature();
      signature += `${docString}\n`;
    }
    const alias = this.alias || this.name;
    const originalName = this.exportNode.name || this.name;
    if (alias !== originalName) {
      signature += `export { ${originalName} as ${alias} };\n`;
    } else {
      signature += `export { ${originalName} };\n`;
    }
    const exportNodeSignature = this.exportNode.toFullSignature(options);
    signature += `\n${exportNodeSignature}`;
    return signature;
  }
  toObject() {
    return {
      ...super.toObject(),
      name: this.name,
      doc: this.doc?.toObject(),
      location: this.location,
      exportNode: this.exportNode.toObject(),
      alias: this.alias
    };
  }
  static fromObject(obj) {
    const name = obj.name;
    const location = obj.location;
    const exportNode = _schemaRegistry().SchemaRegistry.fromObject(obj.exportNode);
    const alias = obj.alias;
    const doc = obj.doc ? _docs().DocSchema.fromObject(obj.doc) : undefined;
    return new ExportSchema(location, name, exportNode, alias, doc);
  }
  static isExportSchema(node) {
    return 'exportNode' in node;
  }
}
exports.ExportSchema = ExportSchema;

//# sourceMappingURL=export.js.map