"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.ModuleSchema = void 0;
function _chalk() {
  const data = _interopRequireDefault(require("chalk"));
  _chalk = function () {
    return data;
  };
  return data;
}
function _schemaNode() {
  const data = require("../schema-node");
  _schemaNode = function () {
    return data;
  };
  return data;
}
function _schemaRegistry() {
  const data = require("../schema-registry");
  _schemaRegistry = function () {
    return data;
  };
  return data;
}
function _interopRequireDefault(e) { return e && e.__esModule ? e : { default: e }; }
class ModuleSchema extends _schemaNode().SchemaNode {
  // exports could either be re exports (export declarations) or nodes with export modifier

  constructor(location, exports, internals) {
    super();
    this.location = location;
    this.exports = exports;
    this.internals = internals;
  }
  getNodes() {
    return [...this.exports, ...this.internals];
  }
  flatExportsRecursively() {
    this.exports = this.exports.reduce((acc, exp) => {
      if (exp instanceof ModuleSchema) {
        exp.flatExportsRecursively();
        if (exp.namespace) return [...acc, exp];
        return [...acc, ...exp.exports];
      }
      return [...acc, exp];
    }, []);
  }
  toString(options) {
    if (!this.namespace) throw new Error('toString() should not be called on a module without namespace, make sure this.flatExportsRecursively() is called');
    const boldUnderline = options?.color ? _chalk().default.bold.underline : str => str;
    const exportsStr = this.exports.map(m => `* ${m.toString(options)}`).join('\n');
    return `${boldUnderline(this.namespace)}\n${exportsStr}`;
  }
  toFullSignature(options) {
    if (!this.namespace) throw new Error('toFullSignature() should not be called on a module without namespace; make sure this.flatExportsRecursively() is called');
    const exportsSignatures = this.exports.map(m => m.toFullSignature(options)).join('\n');
    let signature = `${this.namespace}\n${exportsSignatures}`;
    if (options?.showDocs && this.doc) {
      const docString = this.doc.toFullSignature();
      signature = `${docString}\n${signature}`;
    }
    return signature;
  }
  toObject() {
    return {
      ...super.toObject(),
      exports: this.exports.map(member => member.toObject()),
      internals: this.internals.map(member => member.toObject()),
      namespace: this.namespace
    };
  }
  static fromObject(obj) {
    const location = obj.location;
    const exportNodes = (obj.exports || []).map(member => _schemaRegistry().SchemaRegistry.fromObject(member));
    const internals = (obj.internals || []).map(member => _schemaRegistry().SchemaRegistry.fromObject(member));
    const namespace = obj.namespace;
    const module = new ModuleSchema(location, exportNodes, internals);
    module.namespace = namespace;
    return module;
  }
}
exports.ModuleSchema = ModuleSchema;

//# sourceMappingURL=module.js.map