"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.TypeLiteralSchema = void 0;
function _schemaNode() {
  const data = require("../schema-node");
  _schemaNode = function () {
    return data;
  };
  return data;
}
function _schemaRegistry() {
  const data = require("../schema-registry");
  _schemaRegistry = function () {
    return data;
  };
  return data;
}
/**
 * e.g. `{ a: string; b: number }`
 */
class TypeLiteralSchema extends _schemaNode().SchemaNode {
  constructor(location, members) {
    super();
    this.location = location;
    this.members = members;
  }
  getNodes() {
    return this.members;
  }
  toString() {
    return `{ ${this.members.map(type => type.toString()).join('; ')} }`;
  }
  toFullSignature(options) {
    const indent = level => '  '.repeat(level);
    const level = 0;
    let signature = '';
    signature += '{\n';
    this.members.forEach(member => {
      const memberSignature = member.toFullSignature(options);
      const memberLines = memberSignature.split('\n');
      const indentedLines = memberLines.map(line => indent(level + 1) + line);
      signature += indentedLines.join('\n') + '\n';
    });
    signature += indent(level) + '}';
    return signature;
  }
  toObject() {
    return {
      ...super.toObject(),
      members: this.members.map(type => type.toObject())
    };
  }
  static fromObject(obj) {
    const location = obj.location;
    const members = obj.members.map(type => _schemaRegistry().SchemaRegistry.fromObject(type));
    return new TypeLiteralSchema(location, members);
  }
}
exports.TypeLiteralSchema = TypeLiteralSchema;

//# sourceMappingURL=type-literal.js.map