import { ComponentID } from '@teambit/component';
import { SchemaLocation, SchemaNode } from '../schema-node';
export type PlainTypeRefSchema = {
    name: string;
    componentId?: string;
    packageName?: string;
};
/**
 * can be one of the following:
 * 1. a reference to another "export" in the same component
 * 2  a reference to another declaration in the same file (internal)
 * 3. a reference to another component.
 * 4. a reference to a package.
 */
export declare class TypeRefSchema extends SchemaNode {
    readonly location: SchemaLocation;
    /**
     * name of the reference to type.
     */
    readonly name: string;
    /**
     * target package name. existing if type is defined in different package.
     */
    readonly packageName?: string | undefined;
    /**
     * if the reference is not exported from the component, it can be internal to the file.
     */
    readonly internalFilePath?: string | undefined;
    /**
     *  optional type arguments, e.g. type Foo = Bar<X, Y>. The X and Y are type arguments.
     */
    typeArgs?: SchemaNode[];
    readonly componentId?: ComponentID;
    constructor(location: SchemaLocation, 
    /**
     * name of the reference to type.
     */
    name: string, 
    /**
     * target component id. existing if the type is defined in another component.
     */
    componentId?: ComponentID, 
    /**
     * target package name. existing if type is defined in different package.
     */
    packageName?: string | undefined, 
    /**
     * if the reference is not exported from the component, it can be internal to the file.
     */
    internalFilePath?: string | undefined);
    getNodes(): SchemaNode[];
    withTypeArgs(typeArgs: SchemaNode[]): this;
    toString(options?: {
        color?: boolean;
    }): string;
    private nameToString;
    toFullSignature(options?: {
        showDocs?: boolean;
    }): string;
    /**
     * whether this type was already exported in this component
     */
    isFromThisComponent(): boolean;
    /**
     * whether this type is internal to the file.
     */
    isInternalReference(): boolean;
    /**
     * whether this type is exported from this component.
     */
    isExported(): boolean;
    toObject(): {
        name: string;
        componentId: import("@teambit/component-id").ComponentIdObj | undefined;
        packageName: string | undefined;
        internalFilePath: string | undefined;
        typeArgs: Record<string, any>[] | undefined;
    };
    static fromObject(obj: Record<string, any>): TypeRefSchema;
}
